@@ -29,6 +29,10 @@ class SensorImpactFDD:
         :param root_path: the path that creates folder structure to save data and results. Unless defined, the default
         value is the directory where the current Python script is located.
         """
+        if not os.path.exists("config.json"):
+            gdown.download("https://drive.google.com/file/d/1gteh_rkjhJ7emHs-ISk-2_IGQQRDculu/view?usp=sharing",
+               f'config.json', quiet=False, fuzzy=True)
+
         with open("config.json", "r") as jsonfile:
             self.config = json.load(jsonfile)
 
